@@ -1,6 +1,7 @@
 import warnings
 
 import numpy as np
+from matplotlib.ticker import MaxNLocator
 
 from asreviewcontrib.visualization.plot_base import PlotBase
 
@@ -44,7 +45,7 @@ class PlotInclusions(PlotBase):
             else:
                 lw = 0.7
 
-            myplot = self.ax.errorbar(*inc_found, color=col, lw=lw)
+            myplot = self.ax.errorbar(inc_found[0], inc_found[1], color=col, lw=lw)
             if self.thick[data_key]:
                 self.legend_name.append(f"{data_key}")
                 self.legend_plt.append(myplot)
@@ -79,6 +80,9 @@ class PlotInclusions(PlotBase):
             self.ax.set_xlabel("% Records reviewed")
             self.ax.set_ylabel("% Relevant records found")
 
+        # no decimals on y-axis
+        self.ax.yaxis.set_major_locator(MaxNLocator(integer=True))
+
         self.fig.tight_layout()
 
     def add_WSS(self, *args, **kwargs):  # noqa
